==> zio-aws-networkfirewall_2.12-5.17.174.1-sources.jar: zio/aws/networkfirewall/model/ResourceStatus.scala <==
package zio.aws.networkfirewall.model
import scala.jdk.CollectionConverters._
sealed trait ResourceStatus {
  def unwrap
      : software.amazon.awssdk.services.networkfirewall.model.ResourceStatus
}
object ResourceStatus {
  def wrap(
      value: software.amazon.awssdk.services.networkfirewall.model.ResourceStatus
  ): zio.aws.networkfirewall.model.ResourceStatus = value match {
    case software.amazon.awssdk.services.networkfirewall.model.ResourceStatus.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.networkfirewall.model.ResourceStatus.ACTIVE =>
      val r = ACTIVE
      r
    case software.amazon.awssdk.services.networkfirewall.model.ResourceStatus.DELETING =>
      val r = DELETING
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.networkfirewall.model.ResourceStatus {
    override def unwrap
        : software.amazon.awssdk.services.networkfirewall.model.ResourceStatus =
      software.amazon.awssdk.services.networkfirewall.model.ResourceStatus.UNKNOWN_TO_SDK_VERSION
  }
  case object ACTIVE extends zio.aws.networkfirewall.model.ResourceStatus {
    override def unwrap
        : software.amazon.awssdk.services.networkfirewall.model.ResourceStatus =
      software.amazon.awssdk.services.networkfirewall.model.ResourceStatus.ACTIVE
  }
  case object DELETING extends zio.aws.networkfirewall.model.ResourceStatus {
    override def unwrap
        : software.amazon.awssdk.services.networkfirewall.model.ResourceStatus =
      software.amazon.awssdk.services.networkfirewall.model.ResourceStatus.DELETING
  }
}

==> zio-aws-networkfirewall_2.12-7.21.15.8-sources.jar: zio/aws/networkfirewall/model/ResourceStatus.scala <==
package zio.aws.networkfirewall.model
import scala.jdk.CollectionConverters._
sealed trait ResourceStatus {
  def unwrap
      : software.amazon.awssdk.services.networkfirewall.model.ResourceStatus
}
object ResourceStatus {
  def wrap(
      value: software.amazon.awssdk.services.networkfirewall.model.ResourceStatus
  ): zio.aws.networkfirewall.model.ResourceStatus = value match {
    case software.amazon.awssdk.services.networkfirewall.model.ResourceStatus.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.networkfirewall.model.ResourceStatus.ACTIVE =>
      val r = ACTIVE
      r
    case software.amazon.awssdk.services.networkfirewall.model.ResourceStatus.DELETING =>
      val r = DELETING
      r
    case software.amazon.awssdk.services.networkfirewall.model.ResourceStatus.ERROR =>
      val r = ERROR
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.networkfirewall.model.ResourceStatus {
    override def unwrap
        : software.amazon.awssdk.services.networkfirewall.model.ResourceStatus =
      software.amazon.awssdk.services.networkfirewall.model.ResourceStatus.UNKNOWN_TO_SDK_VERSION
  }
  case object ACTIVE extends zio.aws.networkfirewall.model.ResourceStatus {
    override def unwrap
        : software.amazon.awssdk.services.networkfirewall.model.ResourceStatus =
      software.amazon.awssdk.services.networkfirewall.model.ResourceStatus.ACTIVE
  }
  case object DELETING extends zio.aws.networkfirewall.model.ResourceStatus {
    override def unwrap
        : software.amazon.awssdk.services.networkfirewall.model.ResourceStatus =
      software.amazon.awssdk.services.networkfirewall.model.ResourceStatus.DELETING
  }
  case object ERROR extends zio.aws.networkfirewall.model.ResourceStatus {
    override def unwrap
        : software.amazon.awssdk.services.networkfirewall.model.ResourceStatus =
      software.amazon.awssdk.services.networkfirewall.model.ResourceStatus.ERROR
  }
}
